;**************************************************************************
;* FileName	: LCDTEST.ASM
;* Date 	: 13.03.2002
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Alphanumeric LCD test.
;*		  ==================================
;*		  Test code for HD44780 compatible LCD Module. 
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		     LCD_RS ==| RA2	    RA1 |== RS232-RxD (to MAX232)
;*		     LCD_E  ==| RA3	    RA0 |== RS232-TxD (to MAX232)
;*		       n.c. ==| RA4	   OSC1 |== quartz1
;*		     -reset ==|-MCLR	   OSC2 |== quartz2
;*			GND ==| Vss	    Vdd |== +5V
;*	                  / ==| RB0	    RB7 |== \
;*	  LCD_DATAPORT___/  ==| RB1	    RB6 |==  \___LCD_DATAPORT 
;*		         \  ==| RB2	    RB5 |==  /
;*		          \ ==| RB3	    RB4 |== /
;*			      |_________________|
;*				   PIC16F84 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   13 pin   (   %)
;*		  Data memory	  :    xx /   68 byte  (   %)
;*		  Prog memory	  :   xxx / 1024 word  (   %)
;*		  Timer0	  : 
;*		  Interrupt	  : 
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  13/03/2002 	Initial Release
;*
;**************************************************************************

	list	p=16f84, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f84.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

	__CONFIG _XT_OSC & _WDT_OFF & _PWRTE_ON & _CP_OFF
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode

;***** DEFINES ************************************************************
#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation


xtal_freq	EQU	4 MHz	  	; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency

; ----- porta -------------------------------------------------------------

#define		RS232_TxD	PORTA,0		; out
#define		RS232_RxD	PORTA,1		; in
#define		LCD_RS		PORTA,2		; out
#define		LCD_E		PORTA,3		; out
#define		PORTA_4		PORTA,4		; free (open drain!)

; ----- portb -------------------------------------------------------------

#define		PORTB_0		PORTB,0		; LCD
#define		PORTB_1		PORTB,1		; LCD
#define		PORTB_2		PORTB,2		; LCD
#define		PORTB_3		PORTB,3		; LCD
#define		PORTB_4		PORTB,4		; LCD
#define		PORTB_5		PORTB,5		; LCD
#define		PORTB_6		PORTB,6		; LCD
#define		PORTB_7		PORTB,7		; LCD

#define		LCD_DATAPORT	PORTB		; 


;***** MACROS *************************************************************

	include "..\..\modules\wait.mac"
	include	"..\..\modules\rs232.mac"
	include	"..\..\modules\lcd.mac"

	


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00011111b	; TRISA value (all input)
;trisb_val	EQU	11111111b	; TRISB value (all input)
trisb_val	EQU	00000000b	; TRISB value (all input)
intcon_val	EQU	00100000b	; Interrupt control




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	0Ch
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving



;--------------------------------------------------------------------------

	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector

		clrwdt
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
		movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB

		bank0
		ERRORLEVEL +302
		movlw	intcon_val	
		movwf	INTCON		; set INTCON

;----- inits --------------------------------------------------------------


		RS232_INIT	9600, 8, 1
		RS232_SENDCS	"PIC:"

		LCD_INIT	16, 4, LCD_8BIT


;----- main cycle  --------------------------------------------------------



		LCD_DEFCHAR	0, 8, LCD_logo1
		LCD_PRINTCS	" \x08\x09\x0A\x0B\x0C\x0D"
		LCD_GOTOXY	0,1
		LCD_PRINTCS	" \x0E\x0F Elektronika"


main_loop	RS232_RECEIVE
		LCD_PRINTC	

		goto	main_loop






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************
	
LCD_logo1	dt	  0, 0, 0, 0, 0, 1, 1, 3
		dt	  1, 1, 3, 3, 7,15,14,24
		dt	 19,23,31,31,30,28, 9, 0
		dt	 27,19, 0,11,27,27,27, 0
		dt	 27,31,30,30,31,27,25, 0
		dt	  7,14,31,27,27,31,14, 0
		dt	  7, 7,15,15,30,24, 0, 0
		dt	 24,30,24, 0, 0, 0, 0, 0










;**************************************************************************

	include	"..\..\modules\lcd.inc"
	include "..\..\modules\rs232.inc"
	include "..\..\modules\wait.inc"


	end				  ; end of program








